@@ -48,8 +48,8 @@ class BisectCommonArgs:
         self.parser.add_argument(
             "--log-level",
             default="INFO",
-            help="Configure console logging. Options: %s (default: %%(default)s)"
-            % ", ".join(k for k, v in sorted(LOG_LEVELS.items(), key=lambda x: x[1])),
+            help=f"Configure console logging. Options: "
+            f"{', '.join(k for k, v in sorted(LOG_LEVELS.items(), key=lambda x: x[1]))} (default: %(default)s)",
         )
 
         boundary_args = self.parser.add_argument_group(
@@ -212,7 +212,7 @@ class BisectCommonArgs:
 
         log_level = LOG_LEVELS.get(args.log_level.upper(), None)
         if log_level is None:
-            self.parser.error("Invalid log-level %r" % (args.log_level,))
+            self.parser.error(f"Invalid log-level {args.log_level!r}")
         args.log_level = log_level
 
         if args.config is not None:
