@@ -10,22 +10,28 @@ from contextlib import contextmanager
 from pathlib import Path
 from typing import List, Optional, Iterator
 
-from fuzzfetch import Fetcher
+from fuzzfetch import Fetcher, FetcherException
 
 from .config import BisectionConfig
 
 LOG = logging.getLogger("build-manager")
 
 
+class BuildManagerException(Exception):
+    """
+    Raised when a build cannot be retrieved
+    """
+
+
 class DatabaseManager(object):
     """
     Sqlite3 wrapper class
     """
 
     def __init__(self, db_path: Path) -> None:
-        self.con = sqlite3.connect(db_path)
+        self.con = sqlite3.connect(str(db_path))
         self.cur = self.con.cursor()
-        self.cur.execute("CREATE TABLE IF NOT EXISTS in_use (build_path, pid INT)")
+        self.cur.execute("CREATE TABLE IF NOT EXISTS in_use (build_path TEXT, pid INT)")
         self.cur.execute(
             "CREATE TABLE IF NOT EXISTS download_queue (build_path TEXT primary key, pid INT)"
         )
@@ -39,7 +45,10 @@ class DatabaseManager(object):
             self.con.close()
 
     def __del__(self) -> None:
-        self.close()
+        try:
+            self.close()
+        except sqlite3.ProgrammingError:
+            pass
 
 
 class BuildManager(object):
@@ -68,7 +77,7 @@ class BuildManager(object):
         Enumerate all available builds including their size and stats
         """
         builds = [x for x in self.build_dir.iterdir() if x.is_dir()]
-        return sorted(builds, key=lambda b: os.stat(b).st_atime)
+        return sorted(builds, key=lambda b: b.stat().st_atime_ns)
 
     def remove_old_builds(self) -> None:
         """
@@ -79,13 +88,17 @@ class BuildManager(object):
             for build_path in builds:
                 if self.current_build_size < self.config.persist_limit:
                     break
-
                 res = self.db.cur.execute(
-                    "SELECT * FROM in_use, download_queue "
-                    "WHERE in_use.build_path = ? OR download_queue.build_path = ?",
-                    (str(build_path), str(build_path)),
+                    "SELECT COUNT(1) FROM ("
+                    "SELECT build_path FROM in_use UNION ALL "
+                    "SELECT build_path FROM download_queue"
+                    ") WHERE build_path == ?",
+                    (str(build_path),),
                 )
-                if res.fetchone() is None:
+                result = res.fetchone()
+                assert result is not None
+                build_in_use = result[0]
+                if not build_in_use:
                     LOG.debug("Removing build: %s", build_path)
                     shutil.rmtree(build_path)
                 self.db.con.commit()
@@ -100,11 +113,11 @@ class BuildManager(object):
         :param target: The target to retrieve (i.e. firefox, js, gtest, etc)
         """
         # pylint: disable=protected-access
-        branch = "m-%s" % build._branch[0]
+        branch = f"m-{build._branch[0]}"
         platform = build._platform.system
         flags = build._flags.build_string()
         rev = build.changeset[:12]
-        build_name = "%s-%s-%s%s-%s" % (target, branch, platform, flags, rev)
+        build_name = f"{target}-{branch}-{platform}{flags}-{rev}"
         target_path = self.build_dir / build_name.lower()
         path_string = os.fspath(target_path)
 
@@ -126,7 +139,10 @@ class BuildManager(object):
                 # If the build doesn't exist on disk, download it
                 if not Path.is_dir(target_path):
                     self.remove_old_builds()
-                    build.extract_build([target], target_path)
+                    try:
+                        build.extract_build([target], target_path)
+                    except FetcherException as e:
+                        raise BuildManagerException("Failed to extract build.") from e
             except sqlite3.IntegrityError:
                 LOG.warning(
                     "Another process is attempting to download the build. Waiting"
